%
% M15_SetLineFilter Create and write the command to be sent to the serial port.
% Read the response from the serial port. Check the status code of the response 
% and verify the code to check if it is 'OK'.
%
% function M15_SetLineFilter(setting,amplifiernum)
%
% Author Aarti Goge
%
% This function is used to change the line frequency filter setting for the designated 
% amplifier to either off or on.
%
% Inputs
%    setting: line filter value 
%    amplifiernum: an array of amplifier numbers, range 0 to 32(decimal)
%
% Outputs
%    none
%
% Globals
%    M15_DEBUG: constant value for debugging purposes, M15_DEBUG = 1
%
% Modifications
% 03/06/18 AG First created.
% 03/08/08 AG Introduced global variable M15_DEBUG for debugging purposes.
%
function error = M15_SetLineFilter(setting,amplifiernum)

global M15_Amplifiers M15_OK M15_DEBUG;
error = 0;

switch nargin,   
    
    case 0        
         error('Atleast enter valid line filter setting(off,on).'); 
         
    case 1
        % all(group) channel basis
         amplifiernum = M15_Amplifiers; 
         if (isempty(amplifiernum))
             disp(' ')
             disp(['Please select channels through M15_AllChannelBasis...'])
         end
 end

% initialize parameter1 based on setting('0' for 'off' and '1' for 'on')
if (strcmpi(setting,'off'))
    parameter1 = '0';
elseif (strcmpi(setting,'on'))
    parameter1 = '1';
else
    error('Invalid Input: Please enter valid setting as off or on(case insensitive)');
end

N = max(size(amplifiernum));

for(i=1:N)
    %check if amplifiernum is 1 digit or 2 digit #, if it is >32 throw an
    %error------------------
    if(amplifiernum(i)<0)
        amplifiernumstr = sprintf('%d',amplifiernum(i));
        disp([amplifiernumstr ' is not a valid input']) 
        error('Amplifier number can not be negative. Please enter amplifier number is in the range: 0-32.');
    elseif(amplifiernum(i)<16)
        amplifiernumstr = sprintf('%02X',amplifiernum(i));
    elseif (amplifiernum(i)<33)
        amplifiernumstr = sprintf('%2X',amplifiernum(i));
    else 
        amplifiernumstr = sprintf('%d',amplifiernum(i));
        disp([amplifiernumstr ' is not a valid input']) 
        error('The system has only 8 Quad Amplifier plug-in slots. Hence the appropriate amplifier number is in the range: 0-32.');
    end

    % create the command
    command = ['N' amplifiernumstr parameter1];

    % write the command to the serial port
    M15_SerialWrite(command);

    % read the repsponse from the serial port
    response = M15_SerialRead;

    % check the status code of the response
    [code, errormsg] = M15_StatusCode(response);

    % verify the code to check if it corresponds to 'OK'
    M15_VerifyCode(code,errormsg);
    
    if M15_DEBUG  
        
        if (code==M15_OK)
            amplifiernumstr = sprintf('%d',amplifiernum(i));
            settingstr = sprintf('%s',setting);
            if (amplifiernumstr=='0')
                % current M15 has only 8 amplifiers
                for i=1:8
                    [highfilter linefilter gain lowfilter] = M15_QuerySettings(amplifiernum(i));
                    if (setting~=linefilter)
                        disp('M15_SetLineFilter: Error has occured, query does not confirm the write operation')  
                        error = 1;
                        return
                    end
                end
                disp(['For All Amplifiers: Line Filter = ' settingstr])
                break
            else
                [highfilter linefilter gain lowfilter] = M15_QuerySettings(amplifiernum(i));
                if (strcmpi(settingstr,linefilter))            
                    disp(['Amplifier #' amplifiernumstr ': LineFilter = ' linefilter]) 
                elseif (strfind(linefilter,'null')) % for current M15, 9-32 amplifiers get 'null' response from M15_QuerySettings               
                    disp('M15_SetLineFilter: Error has occured, query does not confirm the write operation')
                    error = 1;
                    return
                end   
                      
            end
        else
            amplifiernumstr = sprintf('%d',amplifiernum(i));
            disp([' for ' amplifiernumstr])
        end
        
    end %end of if M15_DEBUG
    
end % end of for loop

if (error~=1)
    error = 0;
end